@@ -7,12 +7,10 @@ data = None
 def convert(num):
 		return (f"{num:,}")
 class Country:
-	async def __init__(self, country):
+	def __init__(self, country):
 		self.country = country
 		url = f"https://disease.sh/v2/countries/{self.country}"
-		async with aiohttp.ClientSession() as session:
-			async with session.get(url) as resp:
-				shit = resp.json()
+		shit = urlopen(url).json()
 		global data
 		data = shit
 	def total_cases(self):
